define(
//begin v1.x content
({
	widgetLabel: "一括スペル・チェック",
	unfound: "見つかりません",
	skip: "スキップ",
	skipAll: "すべてをスキップ",
	toDic: "辞書に追加",
	suggestions: "修正候補",
	replace: "置換",
	replaceWith: "置き換え",
	replaceAll: "すべてを置換",
	cancel: "キャンセル",
	msg: "ミススペルはありません",
	iSkip: "これをスキップ",
	iSkipAll: "これと類似のものをスキップ",
	iMsg: "スペルの修正候補はありません"
})
//end v1.x content
);
